pub struct BodyError { /* private fields */ }Expand description
An error that can occur while streaming a response body.
This error type wraps any error that might occur during the actual transmission of the response body to the client (e.g., I/O errors from a file being streamed). If the body stream yields an error after headers have already been sent to the client, that error will cause the connection to be aborted — it cannot be converted back to an HTTP error response.
Implementations