pub struct QueryParams(pub HashMap<String, String>);Expand description
Parsed query parameters from the request URL.
Contains a map of query parameter names to their values, with + decoded
as space and percent-encoded sequences decoded. Populated by the app and
stored in request extensions; extract via query_params(&req), which reads a
request with no query string as one with no parameters.
Tuple Fields
0: HashMap<String, String>Trait Implementations
Sourceimpl Clone for QueryParams
impl Clone for QueryParams
Sourcefn clone(&self) -> QueryParams
fn clone(&self) -> QueryParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QueryParams
impl Debug for QueryParams
Sourceimpl Default for QueryParams
impl Default for QueryParams
Sourcefn default() -> QueryParams
fn default() -> QueryParams
Returns the “default value” for a type. Read more