ResponseBody

Type Alias ResponseBody 

pub type ResponseBody = BoxBody<Bytes, BodyError>;
The response body type used by all handlers.

The error type is BodyError, which can represent errors that occur during body streaming (e.g., disk I/O failures while reading a large file). These errors will abort the connection rather than being converted to an HTTP error response.

Aliased Type

pub struct ResponseBody { /* private fields */ }